@@ -44,7 +44,7 @@ bool KontactKCMultiDialogPrivate::resolveChanges(KCModule *currentProxy)
     const int queryUser = KMessageBox::warningTwoActionsCancel(q,
                                                                i18n("The settings of the current module have changed.\n"
                                                                     "Do you want to apply the changes or discard them?"),
-                                                               i18n("Apply Settings"),
+                                                               i18nc("@title:window", "Apply Settings"),
                                                                KStandardGuiItem::apply(),
                                                                KStandardGuiItem::discard(),
                                                                KStandardGuiItem::cancel());
