@@ -143,7 +143,7 @@ int KontactApp::activate(const QStringList &args, const QString &workingDir)
     }
 
     // Start KOrgac in case it's wasn't started on session start.
-    QDBusConnection::sessionBus().interface()->startService(QStringLiteral("org.kde.korgac"));
+    QDBusConnection::sessionBus().interface()->startService(QStringLiteral("org.kde.kalendarac"));
 
     // Handle startup notification and window activation
     // (The first time it will do nothing except note that it was called)
@@ -158,7 +158,6 @@ int main(int argc, char **argv)
     QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
     KontactApp app(argc, &argv);
 
-    KCrash::initialize();
 #if HAVE_STYLE_MANAGER
     KStyleManager::initStyle();
 #else // !HAVE_STYLE_MANAGER
@@ -192,6 +191,7 @@ int main(int argc, char **argv)
     app.setDesktopFileName(QStringLiteral("org.kde.kontact"));
 
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kontact")));
+    KCrash::initialize();
 
     QCommandLineParser *cmdArgs = app.cmdArgs();
     loadCommandLineOptions(cmdArgs);
